@@ -5,7 +5,7 @@ package Geo::Query::LatLong;
 # Author: Reto Schaer
 # Copyright (c) 2007
 #
-our $VERSION = '0.8004';
+our $VERSION = '0.8005';
 ############################################################
 
 use strict;
@@ -99,14 +99,15 @@ Query latitude and longitude from any city in any country.
   print "Latitude and longitude of $CITY: ",
 		$res->{'lat'}, ' / ', $res->{'lng'}, "\n";
 
-  # List all results
+=head3 List all results
+
   foreach (keys %{$res}) {
 	print "$_ = ", $res->{$_}, "\n";
   }
 
 =head2 Another example
 
-  # Switch exactness to "off" increase the chance you get a result.
+Switch exactness to "off" will increase the chance you get a result.
 
   $res = $geo->query( city => 'Unterwalden', country_code => 'SZ', exact => 'off' ); # exact default: on
 
@@ -120,16 +121,35 @@ Query latitude and longitude from any city in any country.
 
   Use the english translations for the city names, e.g. Zurich for Zuerich, Munich for Muenchen.
 
+=head2 Return values
+
+The function query(...) always returns a hash reference. Hash key 'rc' is retured as 0 (Zero) on success and unequal 0 on a failure.
+Additionally it is a good advice to read or display the 'msg' key on a failure to get a hint about the cause.
+
+B<On case the city was not found:>
+
+=item *
+
+Hash key 'rc' returns a number unequal to zero.
+
+=item *
+
+Hash keys 'lat' / 'lng' are being returned as '99' / '99'.
+
 =head2 EXPORT
 
 None by default.
 
-=head1 SEE ALSO
+=head1 Further documentation and feedback
 
 http://meta.pgate.net/perl-modules/
 
 http://www.infocopter.com/perl/modules/
 
+=head1 SEE ALSO
+
+The Geo::Coder::* series.
+
 =head1 AUTHOR
 
 Reto Schaer, E<lt>retoh@cpan.orgE<gt>
